.. _github-stats-3-9-4:

GitHub statistics for 3.9.4 (Dec 13, 2024)
==========================================

GitHub statistics for 2024/11/30 (tag: v3.9.3) - 2024/12/13

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 2 issues and merged 3 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/100?closed=1>`__

The following 3 authors contributed 15 commits.

* Elliott Sales de Andrade
* Scott Shambaugh
* Victor Liu

GitHub issues and pull requests:

Pull Requests (3):

* :ghpull:`29297`: Backport PR #29295 on branch v3.9.x (BLD: Pin meson-python to <0.17.0)
* :ghpull:`29295`: BLD: Pin meson-python to <0.17.0
* :ghpull:`29175`: addressing issue #29156, converted ps to array before slicing

Issues (2):

* :ghissue:`29229`: [Bug]: Icons do not work with GTK
* :ghissue:`29156`: [Bug]: Poly3DCollection initialization cannot properly handle parameter verts when it is a list of nested tuples and shade is False
